pub trait EventIterator<T: Clone, C: Clone> {
// Required method
fn next(&mut self) -> Option<Cow<'_, Event<T, C>>>;
}Expand description
Iterates over contained Event<T, C>.
The EventIterator trait describes types that can iterate over Cows of events,
and which can be used to replay a stream into a new timely dataflow computation.
This method is not simply an iterator because of the lifetime in the result.
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".